##  Choosing the Source Communities
To configure synchronization of the conceptual data layer from Collibra to data object fact sheets, begin by selecting the appropriate communities from Collibra.
  1. In the Collibra Integration Configuration area, go to the Conceptual Data Layer Mapping tab.
  2. Set the mapping to active by selecting the checkbox against Active.
  3. In the Communities list, select the communities that you need.
